@@ -37,6 +37,8 @@ public:
 	void setFolder(const wchar_t* folder);
 	void setCheckbox(const wchar_t* text, bool isActive = true);
 	void setExtIndex(int extTypeIndex);
+	void setSaveAsCopy(bool isSavingAsCopy);
+	bool getOpenTheCopyAfterSaveAsCopy(void);
 
 	void enableFileTypeCheckbox(const std::wstring& text, bool value);
 	bool getFileTypeCheckboxValue() const;
